new;

output file = ccf25.out reset;

load data[20,8] = base1.asc;

x = data[.,3 4];
y = data[.,6];

Nobs = rows(y);            /* Nombre d'observations */
constante = ones(Nobs,1);  /* La constante          */
x = constante~x;
k = cols(x);               /* Nombre d'exogenes     */

beta = invpd(x'x)*x'y;     /* coefficients estimes  */

u = y - x*beta;            /* residus                      */
SCR = u'u;                 /* Somme des carres des residus */
SCT = y'y;                 /* Somme des carres totaux      */
SCE = SCT - SCR;           /* Somme des carres expliques   */
R2 = SCE/SCT;              /* R2 de la regression          */

ddl = Nobs - k;            /* Degre de liberte   */
sigma = sqrt(SCR/ddl);     /* Ecart-type estime  */

Mcov = (sigma^2)*invpd(x'x);  /* Matrice de covariance des coefficients */
stderr = sqrt(diag(Mcov));    /* Ecart-type des coefficients            */

tstudent = beta ./ stderr;            /* Test T de student : beta[i] = 0 */
pvalue = 2*cdftc(abs(tstudent),ddl);  /* Risque de premiere espece       */

du = u - lag1(u);          /* u(t) - u(t-1)                               */
du = trimr(du,1,0);        /* La premiere donnee est une valeur manquante */

DW = sumc(du^2) / sumc(u^2);  /* statistique Durbin-Watson  */

Mcorr = corrvc(Mcov);
Mcorr2 = Mcov ./ stderr ./ stderr';

print ftos(Nobs, "Nombre d'observations : %lf",5,0);
print ftos(k,    "Nombre de regresseurs : %lf",5,0);
print;
print ftos(ddl,  "Degres de liberte :     %lf",5,0);
print;
print ftos(sigma,"Ecart-type estime :     %lf",5,2);
print ftos(R2,   "R2 :                    %lf",5,3);
print ftos(DW,   "Durbin-Watson :         %lf",5,3);
print;
print "      coefficient      ecart-type       T-student      Prob. marginale";
print "----------------------------------------------------------------------";
print beta~stderr~tstudent~pvalue;
print;
print "Matrice de covariance des estimateurs :";
print Mcov;
print;
print "Matrice de correlation des estimateurs :";
print Mcorr;
print Mcorr2;

output off;
