/*
** Le papillon de Lorenz
*/

new;
library ccf,pgraph;

sigma = 10; beta = 8/3; R = 28;

proc lorenz(t,u);
  local x,y,z,dx,dy,dz,du;

  x = u[1]; y = u[2]; z = u[3];

  dx = sigma*(y-x);
  dy = -x*z + R*x - y;
  dz = x*y - beta*z;

  du = dx|dy|dz;

  retp(du);
endp;


u0 = -8|-9|25;
{t,u,du} = RungeKutta4(&lorenz,u0,0,50,2500);

graphset;
  _pdate = ""; _pnum = 2; _pnumht = 0.18;  _paxht = 0.18;
  title("Le papillon de Lorenz");
  xlabel("x");
  ylabel("y");
  zlabel("z");
  graphprt("-c=1 -cf=ccf19a.eps -w=5");
  xyz(u[1:1000,1],u[1:1000,2],u[1:1000,3]);

graphset;
  begwind;
  window(2,2,0);

    _pdate = ""; _pnum = 2; _pnumht = 0.25;  _paxht = 0.25;

  setwind(1);

    xlabel("x");
    ylabel("y");
    xy(u[.,1],u[.,2]);

  setwind(2);

    xlabel("x");
    ylabel("z");
    xy(u[.,1],u[.,3]);

  setwind(3);

    xlabel("y");
    ylabel("z");
    xy(u[.,2],u[.,3]);

  setwind(4);

    xlabel("t");
    ylabel("x");
    xy(t,u[.,1]);

    graphprt("-c=1 -cf=ccf19b.eps -w=5");

  endwind;

